Iterator

Struct Iterator 

pub struct Iterator { /* private fields */ }
Iterator over a flat-tree.

Implementations

Source

impl Iterator

pub fn new(index: u64) -> Self

Create a new iterator.

Examples
use flat_tree::Iterator;
assert_eq!(Iterator::new(0).take(3).collect::<Vec<u64>>(), [2, 4, 6]);
pub fn index(&self) -> u64

Get the current index.

pub fn offset(&self) -> u64

Get the current offset.

pub fn factor(&self) -> u64

Get the current factor.

pub fn seek(&mut self, index: u64)

Seek to a position in the iterator.

Examples
let mut iter = flat_tree::Iterator::new(0);
iter.seek(4);
assert_eq!(iter.next(), Some(6));
iter.seek(2);
assert_eq!(iter.next(), Some(4));
pub fn is_left(&self) -> bool

Check if the position of the iterator is currently on a left node.

Examples
assert_eq!(flat_tree::Iterator::new(0).is_left(), true);
assert_eq!(flat_tree::Iterator::new(2).is_left(), false);
assert_eq!(flat_tree::Iterator::new(1).is_left(), true);
pub fn is_right(&self) -> bool

Check if the position of the iterator is currently on a right node.

Examples
assert_eq!(flat_tree::Iterator::new(0).is_right(), false);
assert_eq!(flat_tree::Iterator::new(2).is_right(), true);
assert_eq!(flat_tree::Iterator::new(1).is_right(), false);
pub fn contains(&self, index: u64) -> bool

Check if the the iterator contains given index.

Examples
let iter = flat_tree::Iterator::new(3);
assert_eq!(iter.contains(0), true);
assert_eq!(iter.contains(1), true);
assert_eq!(iter.contains(2), true);
assert_eq!(iter.contains(3), true);
assert_eq!(iter.contains(4), true);
assert_eq!(iter.contains(5), true);
assert_eq!(iter.contains(6), true);
assert_eq!(iter.contains(7), false);
assert_eq!(iter.contains(8), false);

let iter = flat_tree::Iterator::new(9);
assert_eq!(iter.contains(8), true);
assert_eq!(iter.contains(9), true);
assert_eq!(iter.contains(10), true);
assert_eq!(iter.contains(6), false);
assert_eq!(iter.contains(7), false);
assert_eq!(iter.contains(12), false);
assert_eq!(iter.contains(13), false);

let iter = flat_tree::Iterator::new(8);
assert_eq!(iter.contains(8), true);
assert_eq!(iter.contains(6), false);
assert_eq!(iter.contains(7), false);
assert_eq!(iter.contains(9), false);
assert_eq!(iter.contains(10), false);
pub fn count_nodes(&self) -> u64

Returns how many nodes are in the tree of the current position.

Examples
assert_eq!(flat_tree::Iterator::new(0).count_nodes(), 1);
assert_eq!(flat_tree::Iterator::new(1).count_nodes(), 3);
assert_eq!(flat_tree::Iterator::new(3).count_nodes(), 7);
assert_eq!(flat_tree::Iterator::new(5).count_nodes(), 3);
assert_eq!(flat_tree::Iterator::new(23).count_nodes(), 15);
assert_eq!(flat_tree::Iterator::new(27).count_nodes(), 7);
pub fn count_leaves(&self) -> u64

Returns how many leaves are in the tree of the current position.

Examples
assert_eq!(flat_tree::Iterator::new(0).count_leaves(), 1);
assert_eq!(flat_tree::Iterator::new(1).count_leaves(), 2);
assert_eq!(flat_tree::Iterator::new(2).count_leaves(), 1);
assert_eq!(flat_tree::Iterator::new(3).count_leaves(), 4);
assert_eq!(flat_tree::Iterator::new(5).count_leaves(), 2);
assert_eq!(flat_tree::Iterator::new(23).count_leaves(), 8);
assert_eq!(flat_tree::Iterator::new(27).count_leaves(), 4);
pub fn prev(&mut self) -> u64

Move the cursor and get the previous item from the current position.

Examples
let mut iter = flat_tree::Iterator::new(6);
assert_eq!(iter.prev(), 4);
assert_eq!(iter.prev(), 2);
assert_eq!(iter.prev(), 0);
pub fn sibling(&mut self) -> u64

Get the sibling for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(0).sibling(), 2);
assert_eq!(flat_tree::Iterator::new(1).sibling(), 5);
assert_eq!(flat_tree::Iterator::new(4).sibling(), 6);
pub fn parent(&mut self) -> u64

Get the parent for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(0).parent(), 1);
assert_eq!(flat_tree::Iterator::new(1).parent(), 3);
assert_eq!(flat_tree::Iterator::new(4).parent(), 5);
pub fn left_span(&mut self) -> u64

Get the left_span for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(0).left_span(), 0);
assert_eq!(flat_tree::Iterator::new(1).left_span(), 0);
assert_eq!(flat_tree::Iterator::new(3).left_span(), 0);
assert_eq!(flat_tree::Iterator::new(23).left_span(), 16);
assert_eq!(flat_tree::Iterator::new(27).left_span(), 24);
pub fn right_span(&mut self) -> u64

Get the right_span for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(0).right_span(), 0);
assert_eq!(flat_tree::Iterator::new(1).right_span(), 2);
assert_eq!(flat_tree::Iterator::new(3).right_span(), 6);
assert_eq!(flat_tree::Iterator::new(23).right_span(), 30);
assert_eq!(flat_tree::Iterator::new(27).right_span(), 30);
pub fn left_child(&mut self) -> u64

Get the left_child for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(1).left_child(), 0);
assert_eq!(flat_tree::Iterator::new(3).left_child(), 1);
assert_eq!(flat_tree::Iterator::new(7).left_child(), 3);
pub fn right_child(&mut self) -> u64

Get the right_child for the current position and move the cursor.

Examples
assert_eq!(flat_tree::Iterator::new(1).right_child(), 2);
assert_eq!(flat_tree::Iterator::new(3).right_child(), 5);
assert_eq!(flat_tree::Iterator::new(7).right_child(), 11);
pub fn next_tree(&mut self) -> u64

Move to the next tree from the current position and return new index.

Examples
assert_eq!(flat_tree::Iterator::new(0).next_tree(), 2);
assert_eq!(flat_tree::Iterator::new(1).next_tree(), 4);
assert_eq!(flat_tree::Iterator::new(3).next_tree(), 8);
assert_eq!(flat_tree::Iterator::new(7).next_tree(), 16);
pub fn prev_tree(&mut self) -> u64

Move to the previous tree from the current position and return new index.

Examples
assert_eq!(flat_tree::Iterator::new(0).prev_tree(), 0);
assert_eq!(flat_tree::Iterator::new(1).prev_tree(), 0);
assert_eq!(flat_tree::Iterator::new(2).prev_tree(), 0);
assert_eq!(flat_tree::Iterator::new(3).prev_tree(), 0);
assert_eq!(flat_tree::Iterator::new(7).prev_tree(), 0);
assert_eq!(flat_tree::Iterator::new(5).prev_tree(), 2);
assert_eq!(flat_tree::Iterator::new(9).prev_tree(), 6);
assert_eq!(flat_tree::Iterator::new(11).prev_tree(), 6);
pub fn full_root(&mut self, index: u64) -> bool

Move cursor to the full root of given leaf index that the iterator index is a part of. If the cursor is already there, nothing is changed.

Returns true if a full root exists (moved or not), false if there are no full roots for the cursor or if given index is not a leaf.

See full_roots() for what is meant by a full root.

Examples
let mut iter = flat_tree::Iterator::new(0);
assert_eq!(iter.full_root(0), false);
assert_eq!(iter.full_root(22), true);
assert_eq!(iter.index(), 7);
assert_eq!(iter.next_tree(), 16);
assert_eq!(iter.full_root(22), true);
assert_eq!(iter.index(), 17);
assert_eq!(iter.next_tree(), 20);
assert_eq!(iter.full_root(22), true);
assert_eq!(iter.index(), 20);
assert_eq!(iter.next_tree(), 22);
assert_eq!(iter.full_root(22), false);